Struct InspectorStackBuilder
pub struct InspectorStackBuilder<BLOCK>where
BLOCK: Clone,{Show 14 fields
pub analysis: Option<Arc<Compiler>>,
pub block: Option<BLOCK>,
pub gas_price: Option<u128>,
pub cheatcodes: Option<Arc<CheatsConfig>>,
pub fuzzer: Option<Fuzzer>,
pub trace_mode: TraceMode,
pub logs: Option<bool>,
pub line_coverage: Option<bool>,
pub print: Option<bool>,
pub chisel_state: Option<usize>,
pub enable_isolation: bool,
pub networks: NetworkConfigs,
pub wallets: Option<Wallets>,
pub create2_deployer: Address,
}Fields
analysis: Option<Arc<Compiler>>Solar compiler instance, to grant syntactic and semantic analysis capabilities.
block: Option<BLOCK>The block environment.
Used in the cheatcode handler to overwrite the block environment separately from the execution block environment.
gas_price: Option<u128>The gas price.
Used in the cheatcode handler to overwrite the gas price separately from the gas price in the execution environment.
cheatcodes: Option<Arc<CheatsConfig>>The cheatcodes config.
fuzzer: Option<Fuzzer>The fuzzer inspector and its state, if it exists.
trace_mode: TraceModeWhether to enable tracing and revert diagnostics.
logs: Option<bool>Whether logs should be collected.
- None for no log collection.
- Some(true) for realtime console.log-ing.
- Some(false) for log collection.
line_coverage: Option<bool>Whether line coverage info should be collected.
print: Option<bool>Whether to print all opcode traces into the console. Useful for debugging the EVM.
chisel_state: Option<usize>The chisel state inspector.
enable_isolation: boolWhether to enable call isolation. In isolation mode all top-level calls are executed as a separate transaction in a separate EVM context, enabling more precise gas accounting and transaction state changes.
networks: NetworkConfigsNetworks with enabled features.
wallets: Option<Wallets>The wallets to set in the cheatcodes context.
create2_deployer: AddressThe CREATE2 deployer address.
Implementations
impl<BLOCK> InspectorStackBuilder<BLOCK>where
BLOCK: Clone,
impl<BLOCK> InspectorStackBuilder<BLOCK>where
BLOCK: Clone,
pub fn new() -> InspectorStackBuilder<BLOCK>
pub fn new() -> InspectorStackBuilder<BLOCK>
Create a new inspector stack builder.
pub fn set_analysis(
self,
analysis: Arc<Compiler>,
) -> InspectorStackBuilder<BLOCK>
pub fn set_analysis( self, analysis: Arc<Compiler>, ) -> InspectorStackBuilder<BLOCK>
Set the solar compiler instance that grants syntactic and semantic analysis capabilities
pub fn block(self, block: BLOCK) -> InspectorStackBuilder<BLOCK>
pub fn block(self, block: BLOCK) -> InspectorStackBuilder<BLOCK>
Set the block environment.
pub fn gas_price(self, gas_price: u128) -> InspectorStackBuilder<BLOCK>
pub fn gas_price(self, gas_price: u128) -> InspectorStackBuilder<BLOCK>
Set the gas price.
pub fn cheatcodes(
self,
config: Arc<CheatsConfig>,
) -> InspectorStackBuilder<BLOCK>
pub fn cheatcodes( self, config: Arc<CheatsConfig>, ) -> InspectorStackBuilder<BLOCK>
Enable cheatcodes with the given config.
pub fn wallets(self, wallets: Wallets) -> InspectorStackBuilder<BLOCK>
pub fn wallets(self, wallets: Wallets) -> InspectorStackBuilder<BLOCK>
Set the wallets.
pub fn fuzzer(self, fuzzer: Fuzzer) -> InspectorStackBuilder<BLOCK>
pub fn fuzzer(self, fuzzer: Fuzzer) -> InspectorStackBuilder<BLOCK>
Set the fuzzer inspector.
pub fn chisel_state(self, final_pc: usize) -> InspectorStackBuilder<BLOCK>
pub fn chisel_state(self, final_pc: usize) -> InspectorStackBuilder<BLOCK>
Set the Chisel inspector.
pub fn logs(self, live_logs: bool) -> InspectorStackBuilder<BLOCK>
pub fn logs(self, live_logs: bool) -> InspectorStackBuilder<BLOCK>
Set the log collector, and whether to print the logs directly to stdout.
pub fn line_coverage(self, yes: bool) -> InspectorStackBuilder<BLOCK>
pub fn line_coverage(self, yes: bool) -> InspectorStackBuilder<BLOCK>
Set whether to collect line coverage information.
pub fn print(self, yes: bool) -> InspectorStackBuilder<BLOCK>
pub fn print(self, yes: bool) -> InspectorStackBuilder<BLOCK>
Set whether to enable the trace printer.
pub fn trace_mode(self, mode: TraceMode) -> InspectorStackBuilder<BLOCK>
pub fn trace_mode(self, mode: TraceMode) -> InspectorStackBuilder<BLOCK>
Set whether to enable the tracer.
Revert diagnostic inspector is activated when mode != TraceMode::None
pub fn enable_isolation(self, yes: bool) -> InspectorStackBuilder<BLOCK>
pub fn enable_isolation(self, yes: bool) -> InspectorStackBuilder<BLOCK>
Set whether to enable the call isolation.
For description of call isolation, see InspectorStack::enable_isolation.
pub fn networks(self, networks: NetworkConfigs) -> InspectorStackBuilder<BLOCK>
pub fn networks(self, networks: NetworkConfigs) -> InspectorStackBuilder<BLOCK>
Set networks with enabled features.
pub fn create2_deployer( self, create2_deployer: Address, ) -> InspectorStackBuilder<BLOCK>
pub fn build<FEN>(self) -> InspectorStack<FEN>where
FEN: FoundryEvmNetwork,
<FEN as FoundryEvmNetwork>::EvmFactory: FoundryEvmFactory<BlockEnv = BLOCK>,
pub fn build<FEN>(self) -> InspectorStack<FEN>where
FEN: FoundryEvmNetwork,
<FEN as FoundryEvmNetwork>::EvmFactory: FoundryEvmFactory<BlockEnv = BLOCK>,
Builds the stack of inspectors to use when transacting/committing on the EVM.